package com.example.clbarcodescanner;


import java.math.BigInteger;

import com.cipherlab.sam.GeneralString;
import com.cipherlab.sam.params.ApduOutputData;
import com.cipherlab.sam.params.ClResult;
import com.cipherlab.samapi.SamManager;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;


public class MainActivity extends Activity {


	private SamManager m_SM;
	private EditText etInput = null;
	private TextView tvOutput= null;
	ImageView img = null;
	


	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		m_SM = SamManager.InitInstance(this);
		
		tvOutput = (TextView)findViewById(R.id.tv03); 
		etInput = (EditText)findViewById(R.id.editbox); 
		
		
		img = (ImageView) findViewById(R.id.logo);
		img.setEnabled(false);
		
        img.setOnTouchListener(new OnTouchListener() {
			
			@Override
			public boolean onTouch(View v, MotionEvent event) {
				int action = event.getAction();
		        if (action == MotionEvent.ACTION_UP)
		        {
		        	if (!img.isEnabled())
		        		return false;
		        	
		        	
		        	/// After receive Intent_SAMSERVICE_CONNECTED, then we can use "ExecuteApdu" to send APDU command
		        	
		        	String commandStr = etInput.getText().toString();

		        	int[] cmd=convertTo2DigitAry(commandStr);
		        	
		        	ApduOutputData outputData=new ApduOutputData();
	
		        	if (ClResult.S_OK == m_SM.ExecuteApdu(cmd, outputData))
		        	{
		        		tvOutput.setText("Len is " + outputData.length + "\nData is " +  intArrayToHex(outputData.outputData));
		        	}
		        }
				return false;
			}
		});
        

		IntentFilter filter = new IntentFilter();
		filter.addAction(GeneralString.Intent_SAMSERVICE_CONNECTED);
		registerReceiver(myDataReceiver, filter);
		
		
		
	}
	

	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		
		unregisterReceiver(myDataReceiver);
		
		m_SM.Release();
	}

	
	private final BroadcastReceiver myDataReceiver = new BroadcastReceiver() {
		   @Override
		   public void onReceive(Context context, Intent intent) {
			   if (intent.getAction().equals(GeneralString.Intent_SAMSERVICE_CONNECTED)){
		        	/// make sure this AP does already connect with SAM service (after call SamManager.InitInstance(this)
				   img.setEnabled(true);
				   Toast.makeText(MainActivity.this, m_SM.Get_SamServiceVer(),Toast.LENGTH_LONG).show();
		        }
		           
		   }
	};
	
	private int[] convertTo2DigitAry(String inputStr){
		byte[] b = new BigInteger(inputStr,16).toByteArray();
		int[] intArray = new int[b.length];
		for (int i = 0; i < b.length; intArray[i] = unsignedToBytes(b[i++]));
		return intArray;
	}

	private int unsignedToBytes(byte b) {
		return b & 0xFF;
	}
	
	private String intArrayToHex(int[] a) {
		   StringBuilder sb = new StringBuilder(a.length * 2);
		   for(int b: a)
		      sb.append(String.format("%02x", b & 0xff));
		   return sb.toString();
		}
}
